# Copyright (c) 2017 Hartmut Kaiser
#
# Distributed under the Boost Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

import os
import sys
import platform

if sys.version_info < (3, 6):
    raise Exception("Phylanx requires Python 3.6 or higher.")

PHYLANX_INSTALL_PATH = '/phylanx_src/build'
HPX_INSTALL_PATH = '/root/install/x86'

sys.path.append(os.path.dirname(__file__))
pathenv = os.environ['PATH']


def add_to_environ(path, pathenv):
    return '{}{}{}'.format(path, os.pathsep, pathenv)


try:
    if platform.system() == "Windows":
        phylanx_bindir = PHYLANX_INSTALL_PATH + '\\RelWithDebInfo\\bin'
        hpx_bindir = HPX_INSTALL_PATH + '\\RelWithDebInfo\\bin'
    else:
        phylanx_bindir = PHYLANX_INSTALL_PATH + '/lib'
        hpx_bindir = HPX_INSTALL_PATH + '/lib'

    os.environ['PATH'] = add_to_environ(phylanx_bindir, pathenv)
    os.environ['PATH'] = add_to_environ(hpx_bindir, os.environ['PATH'])

    from phylanx._phylanx import *

except Exception:

    try:
        if platform.system() == "Windows":
            phylanx_bindir = PHYLANX_INSTALL_PATH + '\\Debug\\bin'
            hpx_bindir = HPX_INSTALL_PATH + '\\Debug\\bin'
        else:
            phylanx_bindir = PHYLANX_INSTALL_PATH + '/lib'
            hpx_bindir = HPX_INSTALL_PATH + '/lib'

        os.environ['PATH'] = add_to_environ(phylanx_bindir, pathenv)
        os.environ['PATH'] = add_to_environ(hpx_bindir, os.environ['PATH'])

        from phylanx._phylanxd import *

    except Exception as e:

        print("Couldn't load _phylanx(d) extension module: ", str(e))
        print("sys.path: ", sys.path)
        print("os.environ['PATH']: ", os.environ['PATH'])
        print("phylanx_bindir: ", phylanx_bindir)
        print("hpx_bindir: ", hpx_bindir)

        sys.exit(1)
